//-------------------------------------------------------------------------
/*
Copyright (C) 1996, 2003 - 3D Realms Entertainment
Copyright (C) 2000, 2003 - Matt Saettler (EDuke Enhancements)

This file is part of Enhanced Duke Nukem 3D version 1.5 - Atomic Edition

Duke Nukem 3D is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Original Source: 1996 - Todd Replogle
Prepared for public release: 03/21/2003 - Charlie Wiederhold, 3D Realms

EDuke enhancements integrated: 04/13/2003 - Matt Saettler

Note: EDuke source was in transition.  Changes are in-progress in the
source as it is released.

*/
//-------------------------------------------------------------------------

#include "duke3d.h"

#include "concom.h"

t_voxel_map voxel_map[MAXTILES];

long *apScriptGameEvent[MAXGAMEEVENTS];

long *actorLoadEventScrptr[MAXTILES];

short line_number;

char g_bEnhanced=0;	// are we 'enhanced' (more minerals, etc)

char g_szBuf[1024];

char g_szCompCreator[MAX_COMPHEADERSTRING];
char g_szCompCopyright[MAX_COMPHEADERSTRING];
long g_lKey=0;

bDebugFunStuff=0;

short g_i,g_p;
long g_x;
long *g_t;
spritetype *g_sp;

void VoxelInit(void)
{
	int i;
	
	for(i=0;i<MAXTILES;i++)
		voxel_map[i].voxnum=-1;
}

void VoxelLoadVoxels(void)
{ // load from files into memory.
	int voxcount;
	int i;
AddLog("VoxelLoadVoxels");
	voxcount=0;
	for(i=0;i<MAXTILES;i++)
	{
		if(voxel_map[i].voxnum == -2)
		{
sprintf(g_szBuf,"CP:%s %d Voxel %d was set to %s",__FILE__,__LINE__,i,voxel_map[i].name);
AddLog(g_szBuf);
			voxel_map[i].voxnum=voxcount;
			qloadkvx(voxel_map[i].voxnum,voxel_map[i].name);
			voxcount++;
		}
	}
AddLog("VoxelLoadVoxels:X");
	return;
}

char IsGameEvent(short i)
{
	if (i<0) return 0;
	if (i>=MAXGAMEEVENTS) return 0;
	return (apScriptGameEvent[i]!=NULL);
}

void AddLog(char *psz)
{
	FILE *fp;
	fp=fopen("log.log","a");
	if(!fp)
		return;
	fputs(psz,fp);
	fputs("\n",fp);
	fclose(fp);
	return;
}


MATTGAMEVAR aGameVars[MAXGAMEVARS];
int iGameVarCount=0;

MATTGAMEVAR aDefaultGameVars[MAXGAMEVARS];	// the 'original' values
int iDefaultGameVarCount=0;

void ReadGameVars(long fil)
{
	int i;
	long l;

//AddLog("Reading Game Vars from File");

	 kdfread(&l,sizeof(l),1,fil);
	 kdfread(g_szBuf,l,1,fil);
	 g_szBuf[l]=0;
// AddLog(g_szBuf);

	 FreeGameVars();	// nuke 'em all...
//sprintf(g_szBuf,"CP:%s %d",__FILE__,__LINE__);
//AddLog(g_szBuf);
	kdfread(&iDefaultGameVarCount,sizeof(iDefaultGameVarCount),1,fil);
	kdfread(aDefaultGameVars,sizeof(aDefaultGameVars),1,fil);
	 
	 kdfread(&iGameVarCount,sizeof(iGameVarCount),1,fil);
	 
	 for(i=0;i<iGameVarCount;i++)
	 {
		 kdfread(&(aGameVars[i]),sizeof(MATTGAMEVAR),1,fil);
	 }

//sprintf(g_szBuf,"CP:%s %d",__FILE__,__LINE__);
//AddLog(g_szBuf);
	 for(i=0;i<iGameVarCount;i++)
	 {
	 
		if(aGameVars[i].dwFlags & GAMEVAR_FLAG_PERPLAYER)
		{
			aGameVars[i].plValues=malloc(sizeof(long) * MAXPLAYERS);
		}
		else if( aGameVars[i].dwFlags & GAMEVAR_FLAG_PERACTOR)
		{
			aGameVars[i].plValues=malloc(sizeof(long) * MAXSPRITES);
		}
		else
		{
			// else nothing 'extra...'
			aGameVars[i].plValues=NULL;
		}
	 }
	 
//sprintf(g_szBuf,"CP:%s %d",__FILE__,__LINE__);
//AddLog(g_szBuf);
	 InitGameVarPointers();

//sprintf(g_szBuf,"CP:%s %d",__FILE__,__LINE__);
//AddLog(g_szBuf);
	 for(i=0;i<iGameVarCount;i++)
	 {
	 
		if(aGameVars[i].dwFlags & GAMEVAR_FLAG_PERPLAYER)
		{
//sprintf(g_szBuf,"Reading value array for %s (%d)",aGameVars[i].szLabel,sizeof(long) * MAXPLAYERS);
//AddLog(g_szBuf);
			kdfread(aGameVars[i].plValues,sizeof(long) * MAXPLAYERS, 1, fil);
		}
		else if( aGameVars[i].dwFlags & GAMEVAR_FLAG_PERACTOR)
		{
//sprintf(g_szBuf,"Reading value array for %s (%d)",aGameVars[i].szLabel,sizeof(long) * MAXSPRITES);
//AddLog(g_szBuf);
			kdfread(aGameVars[i].plValues,sizeof(long) * MAXSPRITES, 1, fil);
		}
		// else nothing 'extra...'
	 }

//sprintf(g_szBuf,"CP:%s %d",__FILE__,__LINE__);
//AddLog(g_szBuf);
	 kdfread(apScriptGameEvent,sizeof(apScriptGameEvent),1,fil);
	 for(i=0;i<MAXGAMEEVENTS;i++)
		 if(apScriptGameEvent[i])
	 {
		 l = (long)apScriptGameEvent[i]+(long)&script[0];
		 apScriptGameEvent[i] = (long *)l;
	 }
	 
	 kdfread(&g_bEnhanced, sizeof(g_bEnhanced), 1, fil);

// added 6/25/1	 
	 kdfread(voxel_map,sizeof(voxel_map),1,fil);
	 for(i=0;i<MAXTILES;i++)
	 {
		 if (voxel_map[i].voxnum!=-1)
		 {
sprintf(g_szBuf,"CP:%s %d Voxel %d was set to %s",__FILE__,__LINE__,i,voxel_map[i].name);
AddLog(g_szBuf);
			 voxel_map[i].voxnum=-2; // flag to reload.
		 }
	 }
//
	 
//sprintf(g_szBuf,"CP:%s %d",__FILE__,__LINE__);
//AddLog(g_szBuf);
	 kdfread(&l,sizeof(l),1,fil);
	 kdfread(g_szBuf,l,1,fil);
	 g_szBuf[l]=0;
// AddLog(g_szBuf);
	 

#if 0 
	 {
		 FILE *fp;
AddLog("Dumping Vars...");		 
		 fp=fopen("xxx.txt","w");
		 if(fp)
		 {
			 DumpGameVars(fp);
			 fclose(fp);
		 }
AddLog("Done Dumping...");		 
	 }
#endif
	 
}

void SaveGameVars(FILE *fil)
{
	int i;
	long l;
	
//	 AddLog("Saving Game Vars to File");
	 sprintf(g_szBuf,"Matt Saettler");
	 l=strlen(g_szBuf);
	 dfwrite(&l,sizeof(l),1,fil);
	 dfwrite(g_szBuf,l,1,fil);
	 
	 dfwrite(&iDefaultGameVarCount,sizeof(iDefaultGameVarCount),1,fil);
	 dfwrite(aDefaultGameVars,sizeof(aDefaultGameVars),1,fil);
	 
	 dfwrite(&iGameVarCount,sizeof(iGameVarCount),1,fil);

	 for(i=0;i<iGameVarCount;i++)
	 {
		 dfwrite(&(aGameVars[i]),sizeof(MATTGAMEVAR),1,fil);
	 }
	 
//	   dfwrite(&aGameVars,sizeof(aGameVars),1,fil);

	 for(i=0;i<iGameVarCount;i++)
	 {
		if(aGameVars[i].dwFlags & GAMEVAR_FLAG_PERPLAYER)
		{
//sprintf(g_szBuf,"Writing value array for %s (%d)",aGameVars[i].szLabel,sizeof(long) * MAXPLAYERS);
//AddLog(g_szBuf);
			dfwrite(aGameVars[i].plValues,sizeof(long) * MAXPLAYERS, 1, fil);
		}
		else if( aGameVars[i].dwFlags & GAMEVAR_FLAG_PERACTOR)
		{
//sprintf(g_szBuf,"Writing value array for %s (%d)",aGameVars[i].szLabel,sizeof(long) * MAXSPRITES);
//AddLog(g_szBuf);
			dfwrite(aGameVars[i].plValues,sizeof(long) * MAXSPRITES, 1, fil);
		}
		// else nothing 'extra...'
	 }

	 for(i=0;i<MAXGAMEEVENTS;i++)
	 {
		 if(apScriptGameEvent[i])
		 {
			 l = (long)apScriptGameEvent[i]-(long)&script[0];
			 apScriptGameEvent[i] = (long *)l;
		 }
	 }
	 dfwrite(apScriptGameEvent,sizeof(apScriptGameEvent),1,fil);
	 for(i=0;i<MAXGAMEEVENTS;i++)
	 {
		 if(apScriptGameEvent[i])
		 {
			 l = (long)apScriptGameEvent[i]+(long)&script[0];
			 apScriptGameEvent[i] = (long *)l;
		 }
	 }

	 dfwrite(&g_bEnhanced, sizeof(g_bEnhanced), 1, fil);

// added 6/25/01
	 dfwrite(voxel_map,sizeof(voxel_map),1,fil);
//

	 sprintf(g_szBuf,"EOF: Matt Saettler");
	 l=strlen(g_szBuf);
	 dfwrite(&l,sizeof(l),1,fil);
	 dfwrite(g_szBuf,l,1,fil);
 
}

void DumpGameVars(FILE *fp)
{
	int i;
	if(!fp)
	{
		return;
	}
	fprintf(fp,"// Current Game Definitions\n\n");
	fprintf(fp,"\ninclude enhance.con\n");
	
	fprintf(fp,"\n");
	for(i=0;i<iGameVarCount;i++)
	{
		if(aGameVars[i].dwFlags & (GAMEVAR_FLAG_SECRET) )
		{
			continue; // do nothing...
		}
		else
		{
			fprintf(fp,"gamedef %s ",aGameVars[i].szLabel);
					
			if(aGameVars[i].dwFlags & (GAMEVAR_FLAG_PLONG) )
			{
				fprintf(fp," PLONG");
			}
			else
			{
				fprintf(fp,"%d",aGameVars[i].lValue);
			}
			if(aGameVars[i].dwFlags & (GAMEVAR_FLAG_PERPLAYER) )
			{
				fprintf(fp," GAMEVAR_FLAG_PERPLAYER");
			}
			else if(aGameVars[i].dwFlags & (GAMEVAR_FLAG_PERACTOR) )
			{
				fprintf(fp," GAMEVAR_FLAG_PERACTOR");
			}
			else
			{
				fprintf(fp," %d",aGameVars[i].dwFlags & (GAMEVAR_FLAG_USER_MASK));
			}
			fprintf(fp," // ");
			if(aGameVars[i].dwFlags & (GAMEVAR_FLAG_PLONG)
			   || aGameVars[i].dwFlags & (GAMEVAR_FLAG_SYSTEM)
			  )
			{
				fprintf(fp," (system)");
			}
			if(aGameVars[i].dwFlags & (GAMEVAR_FLAG_READONLY) )
			{
				fprintf(fp," (read only)");
			}
			fprintf(fp,"\n");
		}
	}
	fprintf(fp,"\n// end of game definitions\n");	
}


//BOOL
char AddGameVar(char *pszLabel, long lValue, unsigned long dwFlags)
{
	
	int i;
	int j;

	int b=0;

	if(dwFlags & GAMEVAR_FLAG_PLONG)
		dwFlags|=GAMEVAR_FLAG_SYSTEM;	// force system if PLONG

//sprintf(g_szBuf,"AddGameVar(%s, %d, %X)",pszLabel, lValue, dwFlags);
//AddLog(g_szBuf);

	if(strlen(pszLabel) > (MAXVARLABEL-1) )
	{
		warning++;
		printf("  * WARNING.(L%ld) Variable Name '%s' too long (max is %d)\n",line_number,pszLabel, MAXVARLABEL-1);
		return 0;
	}
	for(i=0;i<iGameVarCount;i++)
	{
		if( strcmp(pszLabel,aGameVars[i].szLabel) == 0 )
		{
			// found it...
			if(	  (aGameVars[i].dwFlags & GAMEVAR_FLAG_DEFAULT)
			   || (aGameVars[i].dwFlags & GAMEVAR_FLAG_SYSTEM)
			  )
			{
//sprintf(g_szBuf,"Replacing %s at %d",pszLabel,i);
//AddLog(g_szBuf);
//b=1;
				// it's OK to replace
				break;
			}
			else
			{
				// it's a duplicate in error
				error++;
				printf("  * ERROR.(L%ld) Duplicate Game definition '%s' ignored.\n",line_number,pszLabel);
				return 0;
			}
		}
	}
	if( i < MAXGAMEVARS)
	{
		// Set values
		if(aGameVars[i].dwFlags & GAMEVAR_FLAG_SYSTEM && !(dwFlags & GAMEVAR_FLAG_PLONG))
		{
//if(b)
//{
//sprintf(g_szBuf,"CP:%s %d",__FILE__,__LINE__);
//AddLog(g_szBuf);
//}
			// if existing is system, they only get to change default value....
			aGameVars[i].lValue=lValue;	
			if(!(dwFlags & GAMEVAR_FLAG_NODEFAULT))
			{
				aDefaultGameVars[i].lValue=lValue;
			}
		}
		else
		{
			strcpy(aGameVars[i].szLabel,pszLabel);
			aGameVars[i].dwFlags=dwFlags;
			if (dwFlags & GAMEVAR_FLAG_PLONG)
			{
				aGameVars[i].plValues=(long*)lValue;
			}
			else
			{
				aGameVars[i].lValue=lValue;
			}
			if(!(dwFlags & GAMEVAR_FLAG_NODEFAULT))
			{
				strcpy(aDefaultGameVars[i].szLabel,pszLabel);
				aDefaultGameVars[i].dwFlags=dwFlags;
				aDefaultGameVars[i].lValue=lValue;
			}
		}
		
		if(i==iGameVarCount)
		{
			// we're adding a new one.
			iGameVarCount++;
			if(!(dwFlags & GAMEVAR_FLAG_NODEFAULT))
			{
				iDefaultGameVarCount++;
			}
		}
		if(aGameVars[i].plValues && !(aGameVars[i].dwFlags & GAMEVAR_FLAG_SYSTEM))
		{
			// only free if not system
//sprintf(g_szBuf,"CP:%s %d",__FILE__,__LINE__);
//AddLog(g_szBuf);
			free(aGameVars[i].plValues);
			aGameVars[i].plValues=NULL;
//sprintf(g_szBuf,"CP:%s %d",__FILE__,__LINE__);
//AddLog(g_szBuf);
		}
		if(aGameVars[i].dwFlags & GAMEVAR_FLAG_PERPLAYER)
		{
			if(!aGameVars[i].plValues)
			{
				aGameVars[i].plValues=malloc(sizeof(long) * MAXPLAYERS);
			}
			for(j=0;j<MAXPLAYERS;j++)
			{
				aGameVars[i].plValues[j]=lValue;
			}
		}
		else if( aGameVars[i].dwFlags & GAMEVAR_FLAG_PERACTOR)
		{
			if(!aGameVars[i].plValues)
			{
				aGameVars[i].plValues=malloc(sizeof(long) * MAXSPRITES);
			}
			for(j=0;j<MAXSPRITES;j++)
			{
				aGameVars[i].plValues[j]=lValue;
			}
		}
		return 1;

	}
	else
	{
		// no room to add...
		return 0;
	}
 
}

int GetGameID(char *szGameLabel)
{
	int i;
	for(i=0;i<iGameVarCount;i++)
	{
		if( strcmp(szGameLabel, aGameVars[i].szLabel) == 0 )
		{
			return i;
		}
	}
	return -1;	
}

long GetDefID(char *szGameLabel)
{
	int i;
	for(i=0;i<iGameVarCount;i++)
	{
		if( strcmp(szGameLabel, aGameVars[i].szLabel) == 0 )
		{
			return i;
		}
	}
	return -1;
	
}

void FreeGameVars(void)
{
	// call this function as many times as needed.
	int i;
//AddLog("FreeGameVars");	
	for(i=0;i<MAXGAMEVARS;i++)
	{
//sprintf(g_szBuf,"Freeing %d (%s)",i,aGameVars[i].szLabel);
//AddLog(g_szBuf);
		if(!(aGameVars[i].dwFlags & GAMEVAR_FLAG_SYSTEM))
		{
//AddLog("FreeGameVars: Was NOT system flag");			
			aGameVars[i].lValue=0;
			aGameVars[i].szLabel[0]=0;
			aGameVars[i].dwFlags=0;
			if(aGameVars[i].plValues)
			{
				free(aGameVars[i].plValues);
			}
		}
		aGameVars[i].plValues=NULL;
	}
	iGameVarCount=0;
//AddLog("Exiting FreeGameVars()");
	return;
}

void ClearGameVars(void)
{
	// only call this function ONCE (at game init)...
	int i;

//AddLog("ClearGameVars");

	for(i=0;i<MAXGAMEVARS;i++)
	{
		aGameVars[i].lValue=0;
		aGameVars[i].szLabel[0]=0;
		aGameVars[i].dwFlags=0;
		aGameVars[i].plValues=NULL;
	}
	iGameVarCount=0;
	iDefaultGameVarCount=0;
	return;
}

void AddSystemVars()
{
	// only call ONCE
	int i;
	char aszBuf[64];

//AddLog("AddSystemVars");

/*

// KICK
gamevar WEAPON0_WORKSLIKE 0 GAMEVAR_FLAG_PERPLAYER
gamevar WEAPON0_CLIP 0 GAMEVAR_FLAG_PERPLAYER
gamevar WEAPON0_RELOAD 30 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON0_FIREDELAY 7 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON0_TOTALTIME 14 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON0_HOLDDELAY 14 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON0_FLAGS WEAPON_FLAG_NOVISIBLE GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON0_SHOOTS KNEE GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON0_SPAWNTIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON0_SPAWN 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON0_SHOTSPERBURST 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON0_INITIALSOUND 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON0_FIRESOUND 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON0_SOUND2TIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON0_SOUND2SOUND 0 GAMEVAR_FLAG_PERPLAYER 

// Pistol
gamevar WEAPON1_WORKSLIKE 1 GAMEVAR_FLAG_PERPLAYER
gamevar WEAPON1_CLIP 12 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON1_RELOAD 50 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON1_FIREDELAY 2 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON1_TOTALTIME 6 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON1_HOLDDELAY 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON1_FLAGS WEAPON_FLAG_AUTOMATIC GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON1_SHOOTS SHOTSPARK1 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON1_SPAWNTIME 2 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON1_SPAWN SHELL GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON1_SHOTSPERBURST 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON1_INITIALSOUND 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON1_FIRESOUND 3 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON1_SOUND2TIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON1_SOUND2SOUND 0 GAMEVAR_FLAG_PERPLAYER 

// Shotgun
gamevar WEAPON2_WORKSLIKE 2 GAMEVAR_FLAG_PERPLAYER
gamevar WEAPON2_CLIP 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON2_RELOAD 13 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON2_FIREDELAY 4 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON2_TOTALTIME 31 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON2_HOLDDELAY 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON2_FLAGS WEAPON_FLAG_CHECKATRELOAD GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON2_SHOOTS SHOTGUN GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON2_SPAWNTIME 24 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON2_SPAWN SHOTGUNSHELL GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON2_SHOTSPERBURST 7 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON2_INITIALSOUND 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON2_FIRESOUND 109 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON2_SOUND2TIME 15 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON2_SOUND2SOUND 169 GAMEVAR_FLAG_PERPLAYER 

// Chaingun
gamevar WEAPON3_WORKSLIKE 3 GAMEVAR_FLAG_PERPLAYER
gamevar WEAPON3_CLIP 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON3_RELOAD 30 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON3_FIREDELAY 1 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON3_TOTALTIME 10 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON3_HOLDDELAY 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON3_FLAGS 84 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON3_SHOOTS CHAINGUN GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON3_SPAWNTIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON3_SPAWN SHELL GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON3_SHOTSPERBURST 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON3_INITIALSOUND 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON3_FIRESOUND 6 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON3_SOUND2TIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON3_SOUND2SOUND 0 GAMEVAR_FLAG_PERPLAYER 

// RPG
gamevar WEAPON4_WORKSLIKE 4 GAMEVAR_FLAG_PERPLAYER
gamevar WEAPON4_CLIP 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON4_RELOAD 30 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON4_FIREDELAY 4 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON4_TOTALTIME 20 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON4_HOLDDELAY 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON4_FLAGS 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON4_SHOOTS RPG GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON4_SPAWNTIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON4_SPAWN 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON4_SHOTSPERBURST 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON4_INITIALSOUND 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON4_FIRESOUND 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON4_SOUND2TIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON4_SOUND2SOUND 0 GAMEVAR_FLAG_PERPLAYER 

// PipeBomb
gamevar WEAPON5_WORKSLIKE 5 GAMEVAR_FLAG_PERPLAYER
gamevar WEAPON5_CLIP 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON5_RELOAD 30 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON5_FIREDELAY 6 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON5_TOTALTIME 19 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON5_HOLDDELAY 12 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON5_FLAGS WEAPON_FLAG_THROWIT GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON5_SHOOTS HEAVYHBOMB GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON5_SPAWNTIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON5_SPAWN 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON5_SHOTSPERBURST 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON5_INITIALSOUND 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON5_FIRESOUND 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON5_SOUND2TIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON5_SOUND2SOUND 0 GAMEVAR_FLAG_PERPLAYER 

// Shrinker
gamevar WEAPON6_WORKSLIKE 6 GAMEVAR_FLAG_PERPLAYER
gamevar WEAPON6_CLIP 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON6_RELOAD 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON6_FIREDELAY 3 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON6_TOTALTIME 12 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON6_HOLDDELAY 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON6_FLAGS WEAPON_FLAG_GLOWS GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON6_SHOOTS SHRINKER GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON6_SPAWNTIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON6_SPAWN 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON6_SHOTSPERBURST 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON6_INITIALSOUND 11 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON6_FIRESOUND 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON6_SOUND2TIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON6_SOUND2SOUND 0 GAMEVAR_FLAG_PERPLAYER 

// Devastator
gamevar WEAPON7_WORKSLIKE 7 GAMEVAR_FLAG_PERPLAYER
gamevar WEAPON7_CLIP 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON7_RELOAD 30 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON7_FIREDELAY 2 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON7_TOTALTIME 5 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON7_HOLDDELAY 5 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON7_FLAGS WEAPON_FLAG_FIREEVERYOTHER GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON7_SHOOTS RPG GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON7_SPAWNTIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON7_SPAWN 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON7_SHOTSPERBURST 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON7_INITIALSOUND 10 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON7_FIRESOUND 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON7_SOUND2TIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON7_SOUND2SOUND 0 GAMEVAR_FLAG_PERPLAYER 

// Tripbomb
gamevar WEAPON8_WORKSLIKE 8 GAMEVAR_FLAG_PERPLAYER
gamevar WEAPON8_CLIP 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON8_RELOAD 30 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON8_FIREDELAY 3 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON8_TOTALTIME 16 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON8_HOLDDELAY 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON8_FLAGS WEAPON_FLAG_STANDSTILL GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON8_SHOOTS HANDHOLDINGLASER GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON8_SPAWNTIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON8_SPAWN 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON8_SHOTSPERBURST 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON8_INITIALSOUND 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON8_FIRESOUND 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON8_SOUND2TIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON8_SOUND2SOUND 0 GAMEVAR_FLAG_PERPLAYER 

// Freezethrower
gamevar WEAPON9_WORKSLIKE 9 GAMEVAR_FLAG_PERPLAYER
gamevar WEAPON9_CLIP 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON9_RELOAD 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON9_FIREDELAY 3 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON9_TOTALTIME 5 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON9_HOLDDELAY 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON9_FLAGS WEAPON_FLAG_FIREEVERYOTHER GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON9_SHOOTS FREEZEBLAST GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON9_SPAWNTIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON9_SPAWN 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON9_SHOTSPERBURST 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON9_INITIALSOUND 10 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON9_FIRESOUND 10 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON9_SOUND2TIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON9_SOUND2SOUND 0 GAMEVAR_FLAG_PERPLAYER 

// ?
gamevar WEAPON10_WORKSLIKE 10 GAMEVAR_FLAG_PERPLAYER
gamevar WEAPON10_CLIP 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON10_RELOAD 10 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON10_FIREDELAY 2 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON10_TOTALTIME 10 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON10_HOLDDELAY 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON10_FLAGS 384 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON10_SHOOTS 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON10_SPAWNTIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON10_SPAWN 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON10_SHOTSPERBURST 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON10_INITIALSOUND 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON10_FIRESOUND 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON10_SOUND2TIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON10_SOUND2SOUND 0 GAMEVAR_FLAG_PERPLAYER 

// Expander
gamevar WEAPON11_WORKSLIKE 11 GAMEVAR_FLAG_PERPLAYER
gamevar WEAPON11_CLIP 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON11_RELOAD 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON11_FIREDELAY 2 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON11_TOTALTIME 5 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON11_HOLDDELAY 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON11_FLAGS WEAPON_FLAG_GLOWS GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON11_SHOOTS GROWSPARK GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON11_SPAWNTIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON11_SPAWN 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON11_SHOTSPERBURST 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON11_INITIALSOUND 388 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON11_FIRESOUND 388 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON11_SOUND2TIME 0 GAMEVAR_FLAG_PERPLAYER 
gamevar WEAPON11_SOUND2SOUND 0 GAMEVAR_FLAG_PERPLAYER
*/	
/////////////////////////////		
		sprintf(aszBuf,"WEAPON%d_WORKSLIKE",KNEE_WEAPON);
		AddGameVar(aszBuf, KNEE_WEAPON, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_CLIP",KNEE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_RELOAD",KNEE_WEAPON);
		AddGameVar(aszBuf, 30, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FIREDELAY",KNEE_WEAPON);
		AddGameVar(aszBuf, 7, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_TOTALTIME",KNEE_WEAPON);
		AddGameVar(aszBuf, 14, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_HOLDDELAY",KNEE_WEAPON);
		AddGameVar(aszBuf, 14, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FLAGS",KNEE_WEAPON);
		AddGameVar(aszBuf, WEAPON_FLAG_NOVISIBLE | WEAPON_FLAG_AUTOMATIC | WEAPON_FLAG_RANDOMRESTART, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOOTS",KNEE_WEAPON);
		AddGameVar(aszBuf, KNEE, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWNTIME",KNEE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWN",KNEE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOTSPERBURST",KNEE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_INITIALSOUND",KNEE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_FIRESOUND",KNEE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2TIME",KNEE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2SOUND",KNEE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

/////////////////////////////
		sprintf(aszBuf,"WEAPON%d_WORKSLIKE",PISTOL_WEAPON);
		AddGameVar(aszBuf, PISTOL_WEAPON, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_CLIP",PISTOL_WEAPON);
#ifdef EDUKE
		AddGameVar(aszBuf, 12, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#else
		AddGameVar(aszBuf, 20, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#endif

		sprintf(aszBuf,"WEAPON%d_RELOAD",PISTOL_WEAPON);
#ifdef EDUKE
//		AddGameVar(aszBuf, 50, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		AddGameVar(aszBuf, 30, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#else
		AddGameVar(aszBuf, 50, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#endif		
		sprintf(aszBuf,"WEAPON%d_FIREDELAY",PISTOL_WEAPON);
		AddGameVar(aszBuf, 2, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_TOTALTIME",PISTOL_WEAPON);
#ifdef EDUKE
		AddGameVar(aszBuf, 5, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#else
		AddGameVar(aszBuf, 5, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#endif
		
		sprintf(aszBuf,"WEAPON%d_HOLDDELAY",PISTOL_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FLAGS",PISTOL_WEAPON);
		AddGameVar(aszBuf, WEAPON_FLAG_AUTOMATIC | WEAPON_FLAG_HOLSTER_CLEARS_CLIP, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOOTS",PISTOL_WEAPON);
		AddGameVar(aszBuf, SHOTSPARK1, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWNTIME",PISTOL_WEAPON);
		AddGameVar(aszBuf, 2, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWN",PISTOL_WEAPON);
		AddGameVar(aszBuf, SHELL, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOTSPERBURST",PISTOL_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_INITIALSOUND",PISTOL_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_FIRESOUND",PISTOL_WEAPON);
		AddGameVar(aszBuf, PISTOL_FIRE, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2TIME",PISTOL_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2SOUND",PISTOL_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

/////////////////////////////
		sprintf(aszBuf,"WEAPON%d_WORKSLIKE",SHOTGUN_WEAPON);
		AddGameVar(aszBuf, SHOTGUN_WEAPON, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_CLIP",SHOTGUN_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_RELOAD",SHOTGUN_WEAPON);
		AddGameVar(aszBuf, 13, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FIREDELAY",SHOTGUN_WEAPON);
		AddGameVar(aszBuf, 4, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_TOTALTIME",SHOTGUN_WEAPON);
		AddGameVar(aszBuf, 31, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_HOLDDELAY",SHOTGUN_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FLAGS",SHOTGUN_WEAPON);
		AddGameVar(aszBuf, WEAPON_FLAG_CHECKATRELOAD, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOOTS",SHOTGUN_WEAPON);
		AddGameVar(aszBuf, SHOTGUN, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWNTIME",SHOTGUN_WEAPON);
		AddGameVar(aszBuf, 24, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWN",SHOTGUN_WEAPON);
		AddGameVar(aszBuf, SHOTGUNSHELL, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOTSPERBURST",SHOTGUN_WEAPON);
		AddGameVar(aszBuf, 7, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_INITIALSOUND",SHOTGUN_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_FIRESOUND",SHOTGUN_WEAPON);
		AddGameVar(aszBuf, SHOTGUN_FIRE, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2TIME",SHOTGUN_WEAPON);
		AddGameVar(aszBuf, 15, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2SOUND",SHOTGUN_WEAPON);
		AddGameVar(aszBuf, SHOTGUN_COCK, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

/////////////////////////////
		sprintf(aszBuf,"WEAPON%d_WORKSLIKE",CHAINGUN_WEAPON);
		AddGameVar(aszBuf, CHAINGUN_WEAPON, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_CLIP",CHAINGUN_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_RELOAD",CHAINGUN_WEAPON);
		AddGameVar(aszBuf, 30, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FIREDELAY",CHAINGUN_WEAPON);
		AddGameVar(aszBuf, 1, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_TOTALTIME",CHAINGUN_WEAPON);
#ifdef EDUKE
		AddGameVar(aszBuf, 10, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#else
		AddGameVar(aszBuf, 12, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#endif
		
		sprintf(aszBuf,"WEAPON%d_HOLDDELAY",CHAINGUN_WEAPON);
#ifdef EDUKE
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#else
		AddGameVar(aszBuf, 10, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#endif
		sprintf(aszBuf,"WEAPON%d_FLAGS",CHAINGUN_WEAPON);
#ifdef EDUKE
		AddGameVar(aszBuf, WEAPON_FLAG_AUTOMATIC | WEAPON_FLAG_FIREEVERYTHIRD | WEAPON_FLAG_AMMOPERSHOT, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#else
		AddGameVar(aszBuf, WEAPON_FLAG_AUTOMATIC | WEAPON_FLAG_FIREEVERYTHIRD | WEAPON_FLAG_AMMOPERSHOT, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#endif

		sprintf(aszBuf,"WEAPON%d_SHOOTS",CHAINGUN_WEAPON);
		AddGameVar(aszBuf, CHAINGUN, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWNTIME",CHAINGUN_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWN",CHAINGUN_WEAPON);
		AddGameVar(aszBuf, SHELL, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOTSPERBURST",CHAINGUN_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_INITIALSOUND",CHAINGUN_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_FIRESOUND",CHAINGUN_WEAPON);
		AddGameVar(aszBuf, CHAINGUN_FIRE, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2TIME",CHAINGUN_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2SOUND",CHAINGUN_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

/////////////////////////////
		sprintf(aszBuf,"WEAPON%d_WORKSLIKE",RPG_WEAPON);
		AddGameVar(aszBuf, RPG_WEAPON, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_CLIP",RPG_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_RELOAD",RPG_WEAPON);
		AddGameVar(aszBuf, 30, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FIREDELAY",RPG_WEAPON);
		AddGameVar(aszBuf, 4, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_TOTALTIME",RPG_WEAPON);
		AddGameVar(aszBuf, 20, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_HOLDDELAY",RPG_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FLAGS",RPG_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOOTS",RPG_WEAPON);
		AddGameVar(aszBuf, RPG, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWNTIME",RPG_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWN",RPG_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOTSPERBURST",RPG_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_INITIALSOUND",RPG_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_FIRESOUND",RPG_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2TIME",RPG_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2SOUND",RPG_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

/////////////////////////////
		sprintf(aszBuf,"WEAPON%d_WORKSLIKE",HANDBOMB_WEAPON);
		AddGameVar(aszBuf, HANDBOMB_WEAPON, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_CLIP",HANDBOMB_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_RELOAD",HANDBOMB_WEAPON);
		AddGameVar(aszBuf, 30, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FIREDELAY",HANDBOMB_WEAPON);
		AddGameVar(aszBuf, 6, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_TOTALTIME",HANDBOMB_WEAPON);
		AddGameVar(aszBuf, 19, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_HOLDDELAY",HANDBOMB_WEAPON);
		AddGameVar(aszBuf, 12, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FLAGS",HANDBOMB_WEAPON);
		AddGameVar(aszBuf, WEAPON_FLAG_THROWIT, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOOTS",HANDBOMB_WEAPON);
		AddGameVar(aszBuf, HEAVYHBOMB, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWNTIME",HANDBOMB_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWN",HANDBOMB_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOTSPERBURST",HANDBOMB_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_INITIALSOUND",HANDBOMB_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_FIRESOUND",HANDBOMB_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2TIME",HANDBOMB_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2SOUND",HANDBOMB_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

/////////////////////////////
		sprintf(aszBuf,"WEAPON%d_WORKSLIKE",SHRINKER_WEAPON);
		AddGameVar(aszBuf, SHRINKER_WEAPON, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_CLIP",SHRINKER_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_RELOAD",SHRINKER_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FIREDELAY",SHRINKER_WEAPON);
#ifdef EDUKE
		AddGameVar(aszBuf, 3, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#else
		AddGameVar(aszBuf, 10, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#endif

		sprintf(aszBuf,"WEAPON%d_TOTALTIME",SHRINKER_WEAPON);
#ifdef EDUKE
		AddGameVar(aszBuf, 12, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#else
		AddGameVar(aszBuf, 30, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#endif

		sprintf(aszBuf,"WEAPON%d_HOLDDELAY",SHRINKER_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FLAGS",SHRINKER_WEAPON);
		AddGameVar(aszBuf, WEAPON_FLAG_GLOWS, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOOTS",SHRINKER_WEAPON);
		AddGameVar(aszBuf, SHRINKER, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWNTIME",SHRINKER_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWN",SHRINKER_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOTSPERBURST",SHRINKER_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_INITIALSOUND",SHRINKER_WEAPON);
		AddGameVar(aszBuf, SHRINKER_FIRE, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_FIRESOUND",SHRINKER_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2TIME",SHRINKER_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2SOUND",SHRINKER_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

/////////////////////////////
		sprintf(aszBuf,"WEAPON%d_WORKSLIKE",DEVISTATOR_WEAPON);
		AddGameVar(aszBuf, DEVISTATOR_WEAPON, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_CLIP",DEVISTATOR_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_RELOAD",DEVISTATOR_WEAPON);
		AddGameVar(aszBuf, 30, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FIREDELAY",DEVISTATOR_WEAPON);
		AddGameVar(aszBuf, 2, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_TOTALTIME",DEVISTATOR_WEAPON);
		AddGameVar(aszBuf, 5, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_HOLDDELAY",DEVISTATOR_WEAPON);
		AddGameVar(aszBuf, 5, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FLAGS",DEVISTATOR_WEAPON);
		AddGameVar(aszBuf, WEAPON_FLAG_FIREEVERYOTHER, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOOTS",DEVISTATOR_WEAPON);
		AddGameVar(aszBuf, RPG, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWNTIME",DEVISTATOR_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWN",DEVISTATOR_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOTSPERBURST",DEVISTATOR_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_INITIALSOUND",DEVISTATOR_WEAPON);
		AddGameVar(aszBuf, CAT_FIRE, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_FIRESOUND",DEVISTATOR_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2TIME",DEVISTATOR_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2SOUND",DEVISTATOR_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

/////////////////////////////
		sprintf(aszBuf,"WEAPON%d_WORKSLIKE",TRIPBOMB_WEAPON);
		AddGameVar(aszBuf, TRIPBOMB_WEAPON, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_CLIP",TRIPBOMB_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_RELOAD",TRIPBOMB_WEAPON);
		AddGameVar(aszBuf, 30, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FIREDELAY",TRIPBOMB_WEAPON);
		AddGameVar(aszBuf, 3, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_TOTALTIME",TRIPBOMB_WEAPON);
		AddGameVar(aszBuf, 16, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_HOLDDELAY",TRIPBOMB_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FLAGS",TRIPBOMB_WEAPON);
		AddGameVar(aszBuf, WEAPON_FLAG_STANDSTILL, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOOTS",TRIPBOMB_WEAPON);
		AddGameVar(aszBuf, HANDHOLDINGLASER, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWNTIME",TRIPBOMB_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWN",TRIPBOMB_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOTSPERBURST",TRIPBOMB_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_INITIALSOUND",TRIPBOMB_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_FIRESOUND",TRIPBOMB_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2TIME",TRIPBOMB_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2SOUND",TRIPBOMB_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

/////////////////////////////
		sprintf(aszBuf,"WEAPON%d_WORKSLIKE",FREEZE_WEAPON);
		AddGameVar(aszBuf, FREEZE_WEAPON, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_CLIP",FREEZE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_RELOAD",FREEZE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FIREDELAY",FREEZE_WEAPON);
		AddGameVar(aszBuf, 3, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_TOTALTIME",FREEZE_WEAPON);
		AddGameVar(aszBuf, 5, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_HOLDDELAY",FREEZE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FLAGS",FREEZE_WEAPON);
		AddGameVar(aszBuf, WEAPON_FLAG_FIREEVERYOTHER, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOOTS",FREEZE_WEAPON);
		AddGameVar(aszBuf, FREEZEBLAST, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWNTIME",FREEZE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWN",FREEZE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOTSPERBURST",FREEZE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_INITIALSOUND",FREEZE_WEAPON);
		AddGameVar(aszBuf, CAT_FIRE, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_FIRESOUND",FREEZE_WEAPON);
		AddGameVar(aszBuf, CAT_FIRE, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2TIME",FREEZE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2SOUND",FREEZE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
/////////////////////////////
		sprintf(aszBuf,"WEAPON%d_WORKSLIKE",HANDREMOTE_WEAPON);
		AddGameVar(aszBuf, HANDREMOTE_WEAPON, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_CLIP",HANDREMOTE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_RELOAD",HANDREMOTE_WEAPON);
#ifdef EDUKE
		AddGameVar(aszBuf, 10, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#else
		AddGameVar(aszBuf, 30, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#endif

		sprintf(aszBuf,"WEAPON%d_FIREDELAY",HANDREMOTE_WEAPON);
		AddGameVar(aszBuf, 2, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_TOTALTIME",HANDREMOTE_WEAPON);
		AddGameVar(aszBuf, 10, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_HOLDDELAY",HANDREMOTE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FLAGS",HANDREMOTE_WEAPON);
		AddGameVar(aszBuf, WEAPON_FLAG_BOMB_TRIGGER | WEAPON_FLAG_NOVISIBLE, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOOTS",HANDREMOTE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWNTIME",HANDREMOTE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWN",HANDREMOTE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOTSPERBURST",HANDREMOTE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_INITIALSOUND",HANDREMOTE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_FIRESOUND",HANDREMOTE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2TIME",HANDREMOTE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2SOUND",HANDREMOTE_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

///////////////////////////////////////////////////////		
		sprintf(aszBuf,"WEAPON%d_WORKSLIKE",GROW_WEAPON);
		AddGameVar(aszBuf, GROW_WEAPON, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_CLIP",GROW_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_RELOAD",GROW_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FIREDELAY",GROW_WEAPON);
#ifdef EDUKE
		AddGameVar(aszBuf, 2, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#else
		AddGameVar(aszBuf, 3, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#endif

		sprintf(aszBuf,"WEAPON%d_TOTALTIME",GROW_WEAPON);
#ifdef EDUKE
		AddGameVar(aszBuf, 5, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#else
		AddGameVar(aszBuf, 30, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
#endif

		sprintf(aszBuf,"WEAPON%d_HOLDDELAY",GROW_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_FLAGS",GROW_WEAPON);
		AddGameVar(aszBuf, WEAPON_FLAG_GLOWS, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOOTS",GROW_WEAPON);
		AddGameVar(aszBuf, GROWSPARK, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWNTIME",GROW_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SPAWN",GROW_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_SHOTSPERBURST",GROW_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_INITIALSOUND",GROW_WEAPON);
		AddGameVar(aszBuf, EXPANDERSHOOT, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
		
		sprintf(aszBuf,"WEAPON%d_FIRESOUND",GROW_WEAPON);
		AddGameVar(aszBuf, EXPANDERSHOOT, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2TIME",GROW_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

		sprintf(aszBuf,"WEAPON%d_SOUND2SOUND",GROW_WEAPON);
		AddGameVar(aszBuf, 0, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

	AddGameVar("GRENADE_LIFETIME", NAM_GRENADE_LIFETIME, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
	AddGameVar("GRENADE_LIFETIME_VAR", NAM_GRENADE_LIFETIME_VAR, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

	AddGameVar("STICKYBOMB_LIFETIME", NAM_GRENADE_LIFETIME, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);
	AddGameVar("STICKYBOMB_LIFETIME_VAR", NAM_GRENADE_LIFETIME_VAR, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

	AddGameVar("TRIPBOMB_CONTROL", TRIPBOMB_TRIPWIRE, GAMEVAR_FLAG_PERPLAYER | GAMEVAR_FLAG_SYSTEM);

	
	AddGameVar("WEAPON", 0, GAMEVAR_FLAG_READONLY | GAMEVAR_FLAG_SYSTEM);
	AddGameVar("WORKSLIKE", 0, GAMEVAR_FLAG_READONLY | GAMEVAR_FLAG_SYSTEM);
	AddGameVar("RETURN", 0, GAMEVAR_FLAG_SYSTEM);
	AddGameVar("ZRANGE", 0, GAMEVAR_FLAG_SYSTEM);
	AddGameVar("ANGRANGE", 0, GAMEVAR_FLAG_SYSTEM);
	AddGameVar("AUTOAIMANGLE", 0, GAMEVAR_FLAG_SYSTEM);
	AddGameVar("LOTAG", 0, GAMEVAR_FLAG_READONLY | GAMEVAR_FLAG_SYSTEM);
	AddGameVar("HITAG", 0, GAMEVAR_FLAG_READONLY | GAMEVAR_FLAG_SYSTEM);
	AddGameVar("TEXTURE", 0, GAMEVAR_FLAG_READONLY | GAMEVAR_FLAG_SYSTEM);
	AddGameVar("THISACTOR", 0, GAMEVAR_FLAG_READONLY | GAMEVAR_FLAG_SYSTEM);
	AddGameVar("ATWITH", 0, GAMEVAR_FLAG_READONLY | GAMEVAR_FLAG_SYSTEM);
	
	SetSystemVarPointers();
}

void SetSystemVarPointers()
{
	AddGameVar("RESPAWN_MONSTERS", (long)&ud.respawn_monsters,GAMEVAR_FLAG_SYSTEM | GAMEVAR_FLAG_PLONG);
	AddGameVar("RESPAWN_ITEMS",(long)&ud.respawn_items, GAMEVAR_FLAG_SYSTEM | GAMEVAR_FLAG_PLONG);
	AddGameVar("RESPAWN_INVENTORY",(long)&ud.respawn_inventory, GAMEVAR_FLAG_SYSTEM | GAMEVAR_FLAG_PLONG);
	AddGameVar("MONSTERS_OFF",(long)&ud.monsters_off, GAMEVAR_FLAG_SYSTEM | GAMEVAR_FLAG_PLONG);
	AddGameVar("MARKER",(long)&ud.marker, GAMEVAR_FLAG_SYSTEM | GAMEVAR_FLAG_PLONG);
	AddGameVar("FFIRE",(long)&ud.ffire, GAMEVAR_FLAG_SYSTEM | GAMEVAR_FLAG_PLONG);
	AddGameVar("LEVEL",(long)&ud.level_number, GAMEVAR_FLAG_SYSTEM | GAMEVAR_FLAG_PLONG | GAMEVAR_FLAG_READONLY);
	AddGameVar("VOLUME",(long)&ud.volume_number, GAMEVAR_FLAG_SYSTEM | GAMEVAR_FLAG_PLONG | GAMEVAR_FLAG_READONLY);

	AddGameVar("COOP",(long)&ud.coop, GAMEVAR_FLAG_SYSTEM | GAMEVAR_FLAG_PLONG);
	AddGameVar("MULTIMODE",(long)&ud.multimode, GAMEVAR_FLAG_SYSTEM | GAMEVAR_FLAG_PLONG);

	AddGameVar("myconnectindex", (long)&myconnectindex, GAMEVAR_FLAG_READONLY | GAMEVAR_FLAG_PLONG | GAMEVAR_FLAG_SYSTEM);
	AddGameVar("screenpeek", (long)&screenpeek, GAMEVAR_FLAG_READONLY | GAMEVAR_FLAG_PLONG | GAMEVAR_FLAG_SYSTEM);

	AddGameVar("gs",(long)&g_gs, GAMEVAR_FLAG_PLONG | GAMEVAR_FLAG_SYSTEM);
	AddGameVar("looking_arc",(long)&g_looking_arc, GAMEVAR_FLAG_PLONG | GAMEVAR_FLAG_SYSTEM);
	AddGameVar("gun_pos",(long)&g_gun_pos, GAMEVAR_FLAG_PLONG | GAMEVAR_FLAG_SYSTEM);
	AddGameVar("weapon_xoffset",(long)&g_weapon_xoffset, GAMEVAR_FLAG_PLONG | GAMEVAR_FLAG_SYSTEM);
	AddGameVar("currentweapon",(long)&g_currentweapon, GAMEVAR_FLAG_PLONG | GAMEVAR_FLAG_SYSTEM);
	AddGameVar("weaponcount",(long)&g_kb, GAMEVAR_FLAG_PLONG | GAMEVAR_FLAG_SYSTEM );
	AddGameVar("looking_angSR1",(long)&g_looking_angSR1, GAMEVAR_FLAG_PLONG | GAMEVAR_FLAG_SYSTEM);
}

void ClearGameEvents()
{
	int i;
	for (i=0;i<MAXGAMEEVENTS;i++)
	{
		apScriptGameEvent[i]=NULL;
	}
}
